@@ -27,8 +27,8 @@ class Mutatie:
     def export(self):
         exported_mutatie_regels = []
 
-        for index, mutatie_regel in enumerate(self.mutatie_regels):
-            exported_mutatie_regels.append({**mutatie_regel.export(), "KostenplaatsID": str(index + 1)})
+        for mutatie_regel in self.mutatie_regels:
+            exported_mutatie_regels.append(mutatie_regel.export())
 
         return dict(
             MutatieNr="99999",
