@@ -26,5 +26,5 @@ class MutatieRegel:
             BTWCode=self.btw_code,
             BTWPercentage=self.btw_percentage,
             TegenrekeningCode=self.tegenrekening_code,
-            KostenplaatsID="",
+            KostenplaatsID=None,
         )
